@@ -11,6 +11,7 @@ class DjangoWatchTowerHandler(watchtower_logging.watchtower_logging.WatchTowerHa
         dev = getattr(settings, 'WT_DEV', False)
         timeout = getattr(settings, 'WT_TIMEOUT', 1.0)
         retry_count = getattr(settings, 'WT_NUM_RETRY', 1)
+        use_fallback = getattr(settings, 'WT_USE_FALLBACK', True)
 
         super().__init__(
             beam_id=settings.WT_BEAM_ID,
@@ -20,4 +21,5 @@ class DjangoWatchTowerHandler(watchtower_logging.watchtower_logging.WatchTowerHa
             flush_interval=-1,
             dev=dev,
             timeout=timeout,
-            retry_count=retry_count)
\ No newline at end of file
+            retry_count=retry_count,
+            use_fallback=use_fallback)
\ No newline at end of file
