@@ -44,13 +44,14 @@ class WatchTowerHandler(logging.Handler):
     A logging handler to send events to a Watch Tower instance
     """
 
-    def __init__(self, beam_id, host=DEFAULT_HOST, token=None, debug=False, flush_interval=5.0,
+    def __init__(self, beam_id, host=DEFAULT_HOST, use_fallback=True, fallback_host=None, token=None, debug=False, flush_interval=5.0,
                  force_keep_ahead=False, protocol='https',
                  queue_size=DEFAULT_QUEUE_SIZE,
-                 retry_backoff=2.0, retry_count=3, timeout=3, verify=True, version=__version__, dev=False):
+                 retry_backoff=2.0, retry_count=2, timeout=1.0, verify=True, version=__version__, dev=False):
         """
         Args:
-            host (str): The Watch Tower host (should include port if necessary
+            host (str): The Watch Tower host (should include port if necessary)
+            fallback_host (str): The Watchtower fallback host, defaults to fallback.<host>
             token (str): Authentication token
             debug (bool): Whether to print debug console messages
             flush_interval (float): How often to push events to Watch Tower in seconds
@@ -69,6 +70,8 @@ class WatchTowerHandler(logging.Handler):
 
         self.beam_id = beam_id
         self.host = host or DEFAULT_HOST
+        self.use_fallback = use_fallback
+        self.fallback_host = fallback_host or 'fallback.' + self.host
         self.token = token
         self.verify = verify
         self.timeout = timeout
@@ -92,6 +95,8 @@ class WatchTowerHandler(logging.Handler):
         self.url = '{protocol}://{host}/api/beams/{beam_id}'.format(protocol=self.protocol,
                                                                     host=self.host,
                                                                     beam_id=self.beam_id)
+        self.fallback_url = '{protocol}://{host}'.format(protocol=self.protocol,
+                                                         host=self.fallback_host)
 
 
         # Keep ahead depends on queue size, so cannot be 0
@@ -212,15 +217,41 @@ class WatchTowerHandler(logging.Handler):
                 payload = '[{payload}]'.format(payload=payload)
 
                 self.write_debug_log("Sending payload: " + payload)
+                do_fallback = False
+
+                try:
+                    r = self.session.post(
+                        self.url,
+                        data=payload,
+                        headers=headers,
+                        verify=self.verify,
+                        timeout=self.timeout
+                    )
+                    if not r.status_code in (200, 201) and r.status_code >= 500:
+                        if self.use_fallback:
+                            do_fallback = True
+                        else:
+                            r.raise_for_status()
+                    else:
+                        r.raise_for_status()
+
+                except (requests.exceptions.ConnectionError, requests.exceptions.Timeout) as e:
+                    if self.use_fallback:
+                        do_fallback = True
+                    else:
+                        raise e
+
+                if do_fallback:
+
+                    rf = self.session.post(
+                        self.fallback_url,
+                        data=payload,
+                        headers=headers,
+                        verify=self.verify,
+                        timeout=self.timeout
+                    )
+                    rf.raise_for_status()
 
-                r = self.session.post(
-                    self.url,
-                    data=payload,
-                    headers=headers,
-                    verify=self.verify,
-                    timeout=self.timeout
-                )
-                r.raise_for_status()  # Throws exception for 4xx/5xx status
                 self.write_debug_log("Payload sent successfully")
 
             except Exception as e:
