@@ -11,6 +11,8 @@ import datetime
 import pytz
 import traceback
 import sys
+import hashlib
+import json
 
 DONE_LEVEL_NUM = logging.INFO + 4
 START_LEVEL_NUM = logging.INFO + 2
@@ -24,6 +26,8 @@ if hasattr(random, 'choices'):
 else:
     from watchtower_logging.utils import random_choices
 
+DEDUP_ID_KEY = 'dedup_id'
+
 class logLevels(object):
 
     DEBUG = logging.DEBUG
@@ -73,6 +77,25 @@ def logaction(self, msg, lvl_num, args, data=None, **kws):
         if not self._execution_id is None:
             extra['execution_id'] = self._execution_id
 
+        if not 'beam_id' in extra:
+            extra['beam_id'] = self.beam_id
+
+        # adding deduplication-id
+        if self.dedup and not DEDUP_ID_KEY in extra:
+            if not self.dedup_keys is None and isinstance(self.dedup_keys, (list, tuple, set)):
+                dedup_data = {k:v for k,v in extra.items() if k in self.dedup_keys}
+                if 'msg' in self.dedup_keys or 'message' in self.dedup_keys:
+                    dedup_data['__msg__'] = msg
+            else:
+                dedup_data = extra
+                dedup_data['__msg__'] = msg
+            dedup_id = hashlib.md5(json.dumps(dedup_data,
+                                              sort_keys=True,
+                                              indent=None,
+                                              separators=(',',':')).encode('utf-8')).hexdigest()
+
+            extra[self.dedup_id_key] = dedup_id
+
         # Yes, logger takes its '*args' as 'args'.
         self._log(lvl_num, msg, args, extra=extra, **kws)
 
@@ -134,7 +157,8 @@ class CustomJsonFormatter(jsonlogger.JsonFormatter):
 
 
 def getLogger(beam_id, name=None, execution_id=None, token=None, host=None, protocol=None, dev=False, default_data=None,
-              level=logLevels.START, debug=False, path=None, console=False, send=True, use_threading=None, catch_all=True):
+              level=logLevels.START, debug=False, path=None, console=False, send=True, use_threading=None, dedup=True,
+              dedup_keys=None, retry_count=3, catch_all=True, dedup_id_key=None, use_fallback=True):
 
     # create logger
     name = name or os.environ.get('FUNCTION_NAME', 'watchtower-logging')
@@ -150,6 +174,10 @@ def getLogger(beam_id, name=None, execution_id=None, token=None, host=None, prot
     logger.setExecutionId = types.MethodType(setExecutionId, logger)
     logger.setLevel(level)
     logger.setDefaultData = types.MethodType(setDefaultData, logger)
+    logger.dedup = dedup
+    logger.dedup_keys = dedup_keys
+    logger.dedup_id_key = dedup_id_key or DEDUP_ID_KEY
+    logger.beam_id = beam_id
 
     if default_data:
         logger.setDefaultData(data=default_data)
@@ -172,7 +200,8 @@ def getLogger(beam_id, name=None, execution_id=None, token=None, host=None, prot
 
             # create watchtower handler and set level
             wh = WatchTowerHandler(beam_id=beam_id, token=token, debug=debug, host=host, protocol=protocol,
-                                   version=__version__, flush_interval=flush_interval, dev=dev)
+                                   use_fallback=use_fallback, retry_count=retry_count, version=__version__,
+                                   flush_interval=flush_interval, dev=dev)
             wh.setLevel(level)
 
             # create formatter
